<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the accounts creation page.
 *
 * @link       https://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Mwb_Cf7_Integration_With_Zoho
 * @subpackage Mwb_Cf7_Integration_With_Zoho/admin/partials/templates
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$data_center = get_option( 'mwb-zcf7-domain' );
$client      = get_option( 'mwb-zcf7-client-id' );
$secret      = get_option( 'mwb-zcf7-secret-id' );
$is_active   = get_option( 'mwb_is_crm_active' );
$token       = Mwb_Cf7_Integration_With_Zoho_Helper::get_token_expiry_details();
$total_count = get_option( 'mwb_zcf7_synced_forms_count' );

?>
<div class="mwb_zcf7__account-wrap">

	<div class="mwb-zcf7__logo-wrap">
		<div class="mwb-zcf7__logo-zoho">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/zoho-logo.png' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
		<div class="mwb-zcf7__logo-contact">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/contact-form.svg' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
	</div>

	<div class="mwb_zcf7_crm_connected <?php echo esc_attr( '1' != $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>">
		<ul>
			<li class="mwb-zcf7__conn-row">
				<div class="mwb-zcf7__left-col">
					<h3><?php echo esc_html_e( 'Connection Authorized', 'mwb-cf7-integration-with-zoho' ); ?></h3>
					<div class="mwb-zcf7-token-notice__wrap">
						<p id="mwb-zcf7-token-notice" >
						<?php if ( ! $token ) : ?>
							<?php esc_html_e( 'Access token has been expired.', 'mwb-cf7-integration-with-zoho' ); ?>
						<?php else : ?>
							<?php echo sprintf( '%s %d %s.', esc_html__( 'Access token will expire in ', 'mwb-cf7-integration-with-zoho' ), esc_html( $token ), esc_html__( ' minute(s)', 'mwb-cf7-integration-with-zoho' ) ); ?>
						<?php endif; ?>
					</p>
					<p><img id ="mwb_zcf7_refresh_token" src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/refresh.svg' ); ?>"></p>
					</div>
				</div>
				<div class="mwb-zcf7__right-col">
					<a id="mwb_zcf7_reauthorize" href="<?php echo esc_url( wp_nonce_url( admin_url( '?mwb_get_zcf7_code=1' ) ) ); ?>" class="mwb-btn mwb-btn--filled"><?php esc_html_e( 'Reauthorize', 'mwb-cf7-integration-with-zoho' ); ?></a>
					<a id="mwb_zcf7_revoke" href="#" class="mwb-btn mwb-btn--filled"><?php esc_html_e( 'Disconnect', 'mwb-cf7-integration-with-zoho' ); ?></a>
				</div>
			</li>
		</ul>
	</div>
	<div class="mwb-dashboard__about <?php echo esc_attr( '1' != $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>">
		<div class="mwb-dashboard__about-list">
			<div class="mwb-content__list-item-text">
				<h2 class="mwb-section__heading"><?php esc_html_e( 'Synced Contact Forms', 'mwb-cf7-integration-with-zoho' ); ?></h2>
				<div class="mwb-dashboard__about-number">
					<span><?php echo esc_html( ! empty( $total_count ) ? $total_count : '0' ); ?></span>
				</div>
				<div class="mwb-dashboard__about-number-desc">
					<p>

						<i><?php esc_html_e( 'Total number of Contact Form 7 submission data which are synced over Zoho CRM.', 'mwb-cf7-integration-with-zoho' ); ?>
						<a href="<?php echo esc_url( admin_url( 'admin.php?page=mwb_zoho_cf7&tab=logs' ) ); ?>" target="_blank"><?php esc_html_e( 'View log', 'mwb-cf7-integration-with-zoho' ); ?></a></i>
					</p>
				</div>
			</div>
			<div class="mwb-content__list-item-image">
				<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/deals.svg' ); ?>" alt="">
			</div>
		</div>
	</div>
	<div class="mwb-content-wrap <?php echo esc_attr( '1' != $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>">
		<ul class="mwb-about__list">
			<li class="mwb-about__list-item">
				<div class="mwb-about__list-item-text">
					<p><?php esc_html_e( 'Need any help ? Check our documentation.', 'mwb-cf7-integration-with-zoho' ); ?></p>
				</div>
				<div class="mwb-about__list-item-btn">
					<a href="<?php echo esc_url( 'https://docs.makewebbetter.com/mwb-cf7-integration-with-zoho/?utm_source=MWB-CF7-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site' ); ?>" class="mwb-btn mwb-btn--filled"><?php esc_html_e( 'Documentation', 'mwb-cf7-integration-with-zoho' ); ?></a>
				</div>
			</li>
			<li class="mwb-about__list-item">
				<div class="mwb-about__list-item-text">
					<p><?php esc_html_e( 'Facing any issue ? Open a support ticket.', 'mwb-cf7-integration-with-zoho' ); ?></p>
				</div>
				<div class="mwb-about__list-item-btn">
					<a href="<?php echo esc_url( 'https://makewebbetter.com/submit-query/?utm_source=MWB-CF7-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site ' ); ?>" class="mwb-btn mwb-btn--filled"><?php esc_html_e( 'Support', 'mwb-cf7-integration-with-zoho' ); ?></a>
				</div>
			</li>
			<li class="mwb-about__list-item">
				<div class="mwb-about__list-item-text">
					<p><?php esc_html_e( 'Need personalized solution, contact us !', 'mwb-cf7-integration-with-zoho' ); ?></p>
				</div>
				<div class="mwb-about__list-item-btn">
					<a href="<?php echo esc_url( 'https://makewebbetter.com/contact-us/?utm_source=MWB-CF7t-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site ' ); ?>" class="mwb-btn mwb-btn--filled"><?php esc_html_e( 'Connect', 'mwb-cf7-integration-with-zoho' ); ?></a>
				</div>
			</li>
		</ul>	
	</div>

	<form method="post" id="mwb_zcf7_account_form">
		<?php wp_nonce_field( 'mwb_zoho_cf7_accounts', 'zoho_cf7_account_nonce' ); ?>

		<p class="<?php echo esc_attr( '1' == $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>" ><?php esc_html_e( 'If you don\'t have a Zoho account, you can ', 'mwb-cf7-integration-with-zoho' ); ?><a href="<?php echo esc_url( 'https://www.zoho.com/' ); ?>" target="_blank"><?php esc_html_e( 'sign up here', 'mwb-cf7-integration-with-zoho' ); ?></a></p>

		<div class="mwb_zcf7_table_wrapper">
			<div class="mwb_zcf7_account_setup <?php echo esc_attr( '1' == $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>"><h2><?php esc_html_e( 'Account', 'mwb-cf7-integration-with-zoho' ); ?></h2></div>
			<input type="hidden" name="mwb_is_crm_active" value="<?php echo esc_html( $is_active ); ?>">
			<table class="mwb_zcf7_table <?php echo esc_attr( '1' == $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>">
				<tbody>

					<!-- Zoho Domain start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Zoho Domain', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'Select Zoho domain', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

							$_domain = ! empty( $data_center ) ? sanitize_text_field( wp_unslash( $data_center ) ) : 'in';
							?>
							<select name="mwb_account[domain]" id="mwb-zcf7-domain" >
								<option value="in" <?php selected( $_domain, 'in' ); ?>><?php esc_html_e( 'India (.in)', 'mwb-cf7-integration-with-zoho' ); ?></option>
								<option value="com.cn" <?php selected( $_domain, 'com.cn' ); ?>><?php esc_html_e( 'China (.com.cn)', 'mwb-cf7-integration-with-zoho' ); ?></option>
								<option value="com.au" <?php selected( $_domain, 'com.au' ); ?>><?php esc_html_e( 'Australia (.com.au)', 'mwb-cf7-integration-with-zoho' ); ?></option>
								<option value="eu" <?php selected( $_domain, 'eu' ); ?>><?php esc_html_e( 'Europe (.eu)', 'mwb-cf7-integration-with-zoho' ); ?></option>
								<option value="com" <?php selected( $_domain, 'com' ); ?>><?php esc_html_e( 'USA & Others (.com)', 'mwb-cf7-integration-with-zoho' ); ?></option>
							</select>
						</td>
					</tr>
					<!-- Zoho domain end -->

					<!-- App ID start  -->
					<tr>
						<th>							
							<label><?php esc_html_e( 'Client ID', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'Enter app id', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

							$app_id = ! empty( $client ) ? sanitize_text_field( wp_unslash( $client ) ) : '';
							?>
							<div class="mwb-zcf7__secure-field">
								<input type="password"  name="mwb_account[app_id]" id="mwb-zcf7-client-id" value="<?php echo esc_html( $app_id ); ?>" required>
								<div class="mwb-zcf7__trailing-icon">
									<span class="dashicons dashicons-visibility mwb-toggle-view"></span>
								</div>
							</div>
						</td>
					</tr>
					<!-- App ID end -->

					<!-- Secret Key start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Secret key', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'Enter secret key', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

							$secret_key = ! empty( $secret ) ? sanitize_text_field( wp_unslash( $secret ) ) : '';
							?>

							<div class="mwb-zcf7__secure-field">
								<input type="password" name="mwb_account[secret_key]" id="mwb-zcf7-secret-id" value="<?php echo esc_html( $secret_key ); ?>" required>
								<div class="mwb-zcf7__trailing-icon">
									<span class="dashicons dashicons-visibility mwb-toggle-view"></span>
								</div>
							</div>
						</td>
					</tr>
					<!-- Secret Key End -->

					<!-- Redirect url start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Redirect URL', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'Enter redirect URL', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );
							?>

							<input type="url" name="mwb_account[redirect_url]" value="<?php echo esc_html( rtrim( admin_url(), '/' ) ); ?>" readonly>
						</td>
					</tr>
					<!-- Redirect url end -->

				</tbody>

				<div class="mwb-zcf7__signup-instruction-wrap <?php echo esc_attr( '1' == $is_active ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>"> 
					<h4><?php esc_html_e( 'Instructions', 'mwb-cf7-integration-with-zoho' ); ?></h4>
					<div class="mwb-zcf7__instruction-icon">
						<span class="mwb-zcf7__instruction-open-icon"></span>
						<span class="mwb-zcf7__instruction-close-icon"></span>
					</div>
					<div class="mwb-zcf7__instruction">
						<p>
							&rarr;<?php esc_html_e( 'Create new client', 'mwb-cf7-integration-with-zoho' ); ?> <a href="<?php echo esc_url( 'https://api-console.zoho.in/' ); ?>" target="_blank"><?php esc_html_e( ' here', 'mwb-cf7-integration-with-zoho' ); ?></a></br>
							&rarr;<?php esc_html_e( 'Choose client type as "Server based"', 'mwb-cf7-integration-with-zoho' ); ?></br>
							&rarr;<?php echo sprintf( '%s (%s)', esc_html__( 'Enter client name', 'mwb-cf7-integration-with-zoho' ), esc_html__( 'For eg. Demo app or My app', 'mwb-cf7-integration-with-zoho' ) ); ?></br>
							&rarr;<?php esc_html_e( 'Enter ', 'mwb-cf7-integration-with-zoho' ); ?><code><?php echo esc_url( admin_url() ); ?></code><?php esc_html_e( 'as redirect URI', 'mwb-cf7-integration-with-zoho' ); ?></br>
							&rarr;<?php esc_html_e( 'Save app', 'mwb-cf7-integration-with-zoho' ); ?>
						</p>
					</div>
				</div>

				<!-- Save & connect account start -->
				<tr>
					<th>
					</th>
					<td>
						<a href="<?php echo esc_url( wp_nonce_url( admin_url( '?mwb_get_zcf7_code=1' ) ) ); ?>" class="mwb-btn mwb-btn--filled mwb_zcf7_submit_account" id="mwb-zcf7-authorize-button" ><?php esc_html_e( 'Authorize', 'mwb-cf7-integration-with-zoho' ); ?></a>
					</td>
				</tr>
				<!-- Save & connect account end -->

			</table>
		</div>
	</form>

</div>
<?php

