<?php
/**
 * The core plugin templates are handled here.
 *
 * @since      1.0.0
 * @package    Mwb_Cf7_Integration_With_Zoho
 * @subpackage Mwb_Cf7_Integration_With_Zoho/includes
 * @author     MakeWebBetter <https://makewebbetter.com>
 */

/**
 * Template manager class, handles plugin templates.
 */
class Mwb_Cf7_Integration_With_Zoho_Template_Manager {


	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;


	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'ZOHO_CF7_INTEGRATION_VERSION' ) ) {
			$this->version = ZOHO_CF7_INTEGRATION_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'mwb-cf7-integration-with-zoho';
	}

	/**
	 * Add a header panel in the screen of the plugin.
	 * Returns :: HTML
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function render_header_content_start() {

		/* Header content start. */
		?>
		<meta charset="UTF-8">
		<meta name="viewport" content="width=device-width, initial-scale=1.0">
		<main class="mwb-zcf7-main">
			<header class="mwb-zcf7-header">
				<h1 class="mwb-zcf7-header__title"><?php esc_html_e( 'MWB CF7 Integration with ZOHO CRM', 'mwb-cf7-integration-with-zoho' ); ?></h1>
				<span class="mwb-wfw-version"><?php echo sprintf( 'v%s', esc_html( ZOHO_CF7_INTEGRATION_VERSION ) ); ?></span>
			</header>
		<?php
		/* Header content end. */
	}

	/**
	 * Add a header panel for all screens in plugin.
	 * Returns :: HTML
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function render_navigation_tab() {

		$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field( wp_unslash( $_GET['tab'] ) ) : 'accounts'; // @codingStandardsIgnoreLine

		/* Tabs section start. */
		?>
		<nav class="mwb-zcf7-navbar">
			<div class="mwb-zcf7-nav-collapse">
				<ul class="mwb-zcf7-nav mwb-zcf7-nav-tabs" role="tablist">
					<?php $tabs = $this->retrieve_nav_tabs(); ?>
					<?php if ( ! empty( $tabs ) && is_array( $tabs ) ) : ?>
						<?php foreach ( $tabs as $href => $label ) : ?>
							<li class="mwb-zcf7-nav-item">
								<a class="mwb-zcf7-nav-link nav-tab <?php echo esc_html( $active_tab == $href ? 'nav-tab-active' : '' ); // @codingStandardsIgnoreLine ?>" href="?page=mwb_zoho_cf7&tab=<?php echo esc_html( $href ); ?>"><?php echo esc_html( $label ); ?></a>
							</li>
						<?php endforeach; ?>
					<?php endif; ?>
				</ul>
			</div>
		</nav>

		<?php
		/* Tabs section end */

		switch ( $active_tab ) {

			case 'accounts':
				require_once ZOHO_CF7_INTEGRATION_DIRPATH_ADMIN . 'templates/zoho-cf7-accounts.php';
				break;

			case 'feeds':
				require_once ZOHO_CF7_INTEGRATION_DIRPATH_ADMIN . 'templates/zoho-cf7-feeds-list.php';
				break;

			case 'logs':
				require_once ZOHO_CF7_INTEGRATION_DIRPATH_ADMIN . 'templates/zoho-cf7-logs-list.php';
				break;

			case 'settings':
				require_once ZOHO_CF7_INTEGRATION_DIRPATH_ADMIN . 'templates/zoho-cf7-settings.php';
				break;

			case 'overview':
				require_once ZOHO_CF7_INTEGRATION_DIRPATH_ADMIN . 'templates/zoho-cf7-overview.php';
				break;

			default:
				'';

		}

	}

	/**
	 * Selected Tab settings Screen.
	 * Returns :: HTML
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function render_settings_screen() {

		/* Page settings section start */
		?>
		<div class="mwb-zcf7-container">
			<div class="mwb-zcf7-row">
				<div class="mwb-zcf7-desc">
					<form method="post" action="#" class="mwb-zcf7-output-form"></form>
				</div>
			</div>
		</div>
		<?php
		/* Page setting section end */
	}

	/**
	 * Add a header panel end for all screens in plugin.
	 * Returns :: HTML
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function render_header_content_end() {

		/* Header end start */
		?>

			<div class="mwb-zcf7_save-wrapper is-hidden">
			</div>
		</main>

		<?php
		/* Header section end */
	}

	/**
	 * Get all nav tabs of current screen.
	 *
	 * @author MakeWebBetter <plugins@makewebbetter.com>
	 * @return array An array of screen tabs.
	 */
	public function retrieve_nav_tabs() {

		$current_screen = ! empty( $_GET['page'] ) ? sanitize_text_field( wp_unslash( $_GET['page'] ) ) : false; // @codingStandardsIgnoreLine

		$tabs = '';

		switch ( $current_screen ) {

			case 'mwb_zoho_cf7':
				$tabs = array(
					'accounts' => esc_html__( 'Zoho Accounts', 'mwb-cf7-integration-with-zoho' ),
					'feeds'    => esc_html__( 'Zoho Feeds', 'mwb-cf7-integration-with-zoho' ),
					'logs'     => esc_html__( 'Zoho Logs', 'mwb-cf7-integration-with-zoho' ),
					'settings' => esc_html__( 'Settings', 'mwb-cf7-integration-with-zoho' ),
					'overview' => esc_html__( 'Overview', 'mwb-cf7-integration-with-zoho' ),
				);
				break;
		}

		return apply_filters( $current_screen . '_tab', $tabs );
	}

}

