<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://makewebbetter.com
 * @since             1.0.0
 * @package           Mwb_Cf7_Integration_With_Zoho
 *
 * @wordpress-plugin
 * Plugin Name:       MWB CF7 Integration with ZOHO CRM
 * Plugin URI:        https://wordpress.org/plugins/mwb-cf7-integration-with-zoho-crm
 * Description:       MWB CF7 Integration with ZOHO CRM plugin integrates your ZOHO CRM account with CF7, sending all data over ZOHO CRM as per its available modules.
 * Version:           1.0.0
 * Author:            MakeWebBetter
 * Author URI:        https://makewebbetter.com/?utm_source=MWB-CF7-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site
 *
 * Requires at least: 4.0
 * Tested up to:      5.7.1
 *
 * License:           GPL-3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain:       mwb-cf7-integration-with-zoho
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Check for plugin dependency
 */
function mwb_zoho_cf7_plugin_activation() {
	$active['status'] = false;
	$active['msg']    = 'cf7_inactive';

	if ( true === mwb_zoho_cf7_is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) ) {
		$active['status'] = true;
		$active['msg']    = '';
	}

	return $active;
}

/**
 * Function to check for plugin activation.
 *
 * @param string $slug Slug of the plugin.
 * @return bool
 */
function mwb_zoho_cf7_is_plugin_active( $slug = '' ) {

	if ( empty( $slug ) ) {
		return;
	}

	$active_plugins = get_option( 'active_plugins', array() );

	if ( is_multisite() ) {

		$active_plugins = array_merge( $active_plugins, get_option( 'active_sitewide_plugins', array() ) );
	}

	return in_array( $slug, $active_plugins, true ) || array_key_exists( $slug, $active_plugins );
}

$zoho_cf7_plugin_activation = mwb_zoho_cf7_plugin_activation();

if ( true == $zoho_cf7_plugin_activation['status'] ) { // @codingStandardsIgnoreLine

	/**
	 * Currently plugin version.
	 * Start at version 1.0.0 and use SemVer - https://semver.org
	 * Rename this for your plugin and update it as you release new versions.
	 */
	define( 'ZOHO_CF7_INTEGRATION_VERSION', '1.0.0' );

	// Define all the necessary details of the plugin.

	define( 'ZOHO_CF7_INTEGRATION_URL', plugin_dir_url( __FILE__ ) ); // Plugin URL directory path.

	define( 'ZOHO_CF7_INTEGRATION_DIRPATH', plugin_dir_path( __FILE__ ) ); // Plugin filesystem directory path.

	define( 'ZOHO_CF7_INTEGRATION_DIRPATH_ADMIN', plugin_dir_path( __FILE__ ) . 'admin/partials/' ); // Plugin filesystem path to admin.

	/**
	 * The code that runs during plugin activation.
	 * This action is documented in includes/class-mwb-cf7-integration-with-zoho-activator.php
	 */
	function activate_zoho_cf7_integration() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-mwb-cf7-integration-with-zoho-activator.php';
		Mwb_Cf7_Integration_With_Zoho_Activator::activate();
	}

	/**
	 * The code that runs during plugin deactivation.
	 * This action is documented in includes/class-mwb-cf7-integration-with-zoho-deactivator.php
	 */
	function deactivate_zoho_cf7_integration() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-mwb-cf7-integration-with-zoho-deactivator.php';
		Mwb_Cf7_Integration_With_Zoho_Deactivator::deactivate();
	}

	// Add settings link in plugin action links.
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'zoho_cf7_settings_link' );

	/**
	 * Add settings link callback.
	 *
	 * @since 1.0.0
	 * @param string $links link to the admin area of the plugin.
	 */
	function zoho_cf7_settings_link( $links ) {

		$plugin_links = array(
			'<a href="' . admin_url( 'admin.php?page=mwb_zoho_cf7&tab=accounts' ) . '">' . esc_html__( 'Settings', 'mwb-cf7-integration-with-zoho' ) . '</a>',
		);

		return array_merge( $plugin_links, $links );
	}

	add_filter( 'plugin_row_meta', 'zoho_cf7_important_links', 10, 2 );

	/**
	 * Add custom links.
	 *
	 * @param   string $links link to index file of plugin.
	 * @param   string $file index file of plugin.
	 *
	 * @since    1.0.0
	 */
	function zoho_cf7_important_links( $links, $file ) {

		if ( strpos( $file, 'mwb-cf7-integration-with-zoho.php' ) !== false ) {

			$row_meta = array(
				'demo'    => '<a href="' . esc_url( 'https://demo.makewebbetter.com/mwb-cf7-integration-with-zoho-crm/?utm_source=MWB-CF7-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site' ) . '" target="_blank"><img src="' . ZOHO_CF7_INTEGRATION_URL . 'admin/images/Demo.svg" style="width: 20px;padding-right: 5px;"></i>' . esc_html__( 'Demo', 'mwb-cf7-integration-with-zoho' ) . '</a>',
				'doc'     => '<a href="' . esc_url( 'https://docs.makewebbetter.com/mwb-cf7-integration-with-zoho/?utm_source=MWB-CF7-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site ' ) . '" target="_blank"><img src="' . ZOHO_CF7_INTEGRATION_URL . 'admin/images/Documentation.svg" style="width: 20px;padding-right: 5px;"></i>' . esc_html__( 'Documentation', 'mwb-cf7-integration-with-zoho' ) . '</a>',
				'support' => '<a href="' . esc_url( 'https://makewebbetter.com/submit-query/?utm_source=MWB-CF7-org&utm_medium=MWB-org-backend&utm_campaign=MWB-CF7-site' ) . '" target="_blank"><img src="' . ZOHO_CF7_INTEGRATION_URL . 'admin/images/Support.svg" style="width: 20px;padding-right: 5px;"></i>' . esc_html__( 'Support', 'mwb-cf7-integration-with-zoho' ) . '</a>',
			);

			return array_merge( $links, $row_meta );
		}

		return (array) $links;
	}

	register_activation_hook( __FILE__, 'activate_zoho_cf7_integration' );
	register_deactivation_hook( __FILE__, 'deactivate_zoho_cf7_integration' );

	/**
	 * The core plugin class that is used to define internationalization,
	 * admin-specific hooks, and public-facing site hooks.
	 */
	require plugin_dir_path( __FILE__ ) . 'includes/class-mwb-cf7-integration-with-zoho.php';

	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 * @since    1.0.0
	 */
	function run_zoho_cf7_integration() {

		$plugin = new Mwb_Cf7_Integration_With_Zoho();
		$plugin->run();

	}
	run_zoho_cf7_integration();

} else {

	// Deactivate the plugin if Contact form does not active.
	add_action( 'admin_init', 'mwb_zoho_cf7_activation_failure' );

	/**
	 * Deactivate the plugin.
	 */
	function mwb_zoho_cf7_activation_failure() {

		deactivate_plugins( plugin_basename( __FILE__ ) );
	}

	// Add admin error notice.
	add_action( 'admin_notices', 'mwb_zoho_cf7_activation_notice' );

	/**
	 * This function displays plugin activation error notices.
	 */
	function mwb_zoho_cf7_activation_notice() {

		global $zoho_cf7_plugin_activation;

		// To hide Plugin activated notice.
		unset( $_GET['activate'] ); // @codingStandardsIgnoreLine

		?>

		<?php if ( 'cf7_inactive' === $zoho_cf7_plugin_activation['msg'] ) { ?>

			<div class="notice notice-error is-dismissible">
				<p><strong><?php esc_html_e( 'Contatc Form 7', 'mwb-cf7-integration-with-zoho' ); ?></strong><?php esc_html_e( ' is not activated, Please activate Contact Form 7 first to activate ', 'mwb-cf7-integration-with-zoho' ); ?><strong><?php esc_html_e( ' MWB CF7 Integration with ZOHO CRM', 'mwb-cf7-integration-with-zoho' ); ?></strong><?php esc_html_e( '.', 'mwb-cf7-integration-with-zoho' ); ?></p>
			</div>

			<?php
		}
	}
}
